.. include:: ../../README.rst

.. ldcpy documentation master file, created by
   sphinx-quickstart on Fri May 29 17:52:31 2020.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Documentation
=================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   installation.rst
   development.rst
   api.rst
   examples.rst


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
